@@ -18,11 +18,11 @@ mixplot <- function(
 	# Colors for the categories or single observations if categories are not present
 	col = palette(),
 	# Should lines be drawn to represent one of the variables if the other one is missing in a 2-dim scatterplot
-	na.lines = T,
+	na.lines = TRUE,
 	# Plot origin {0,0} using vertical and horizontal ablines
-	origin = F,
+	origin = FALSE,
 	# Should marginal distributions be plotted, value of 0/FALSE/"no"/"none", 1/TRUE/"rug", 2/"hist"
-	marginal = F,
+	marginal = FALSE,
 	# Layout heights
 	lhei,
 	# Layout widths
@@ -45,9 +45,9 @@ mixplot <- function(
 	ctgr <- c("factor", "character")
 	
 	# Extract types for the columns, cast x to data.frame if necessary
-	if(class(x)=="data.frame"){
+	if(inherits(x, "data.frame")){
 		colclass <- lapply(x, FUN=class)
-	}else if(class(x)=="matrix"){
+	}else if(inherits(x, "matrix")){
 		colclass <- class(x[1,1])
 	}else{
 		x <- as.data.frame(x)
@@ -294,7 +294,7 @@ hmap <- function(
 	# Plotting region settings
 	#
 	# Whether we want to add to an existing region or create a new one
-	add = F,
+	add = FALSE,
 	# x and y axis limits in the heatmap itself
 	# NOTE! This does not include the top and left dendrograms or row and column labels 
 	# (see parameters leftlim, toplim, rightlim, bottomlim for these)
@@ -354,10 +354,10 @@ hmap <- function(
 	valseq = seq(from=min(x, na.rm=na.rm), to=max(x, na.rm=na.rm), length.out=nbins),	
 	# Should row names be plotted (using text-func),
 	# if boolean, then rownames(x) will be plotted. If it is a custom vector of length nrow(x), then these names will be plotted instead
-	namerows = T,
+	namerows = TRUE,
 	# Should column names be plotted (using text-func)
 	# if boolean, then colnames(x) will be plotted. If it is a custom vector of length ncol(x), then these names will be plotted instead
-	namecols = T,
+	namecols = TRUE,
 	
 	# Additional parameters
 	...
@@ -557,6 +557,10 @@ hmap <- function(
 	
 	# Reorder rows and columns for the color intervals according to the respective dendrograms
 	intervalmat <- intervalmat[rev(order.row), order.col] # Notice that y-axis was reversed
+	# Also reorder the lty, lwd and border matrices in case user is annotating certain elements
+	lty <- lty[rev(order.row), order.col]
+	lwd <- lwd[rev(order.row), order.col]
+	border <- border[rev(order.row), order.col]
 	
 	# Plotting the rectangles for the heatmap itself
 	for(row in 1:nr){
@@ -650,7 +654,9 @@ hmap.key <- function(
 	# Text size
 	cex = 0.5,
 	# Text position
-	pos = 3#,
+	pos = 3, #,
+	# Text offset in relation to ticks
+	offset = c(0,0)
 
 	# Additional parameters
 	#...
@@ -676,7 +682,7 @@ hmap.key <- function(
 	where <- findInterval(at, vec=h$valseq)
 	where <- where[!where==0]
 	for(w in 1:length(where)){
-		text(x=xseq[where[w]], y=y0, pos=pos, labels=round(at[w],3), cex=cex) # Text labels above lower text boundary box
+		text(x=xseq[where[w]]+offset[1], y=y0+offset[2], pos=pos, labels=round(at[w],3), cex=cex) # Text labels above lower text boundary box
 		segments(x0=xseq[where[w]], x1=xseq[where[w]], y0=ymid, y1=ytick, col="black")
 	}
 	
